# Table of Contents

- [ai-governance-and-adoption-standardize-usage](<./ai-governance-and-adoption-standardize-usage.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 4: Standardize AI Usage](<./Step-4-Standardize-AI-Usage.md>)
  - [Tech Radar Report for IT Components](<./Step-4-Standardize-AI-Usage/Tech-Radar-Report-for-IT-Components.md>)
  - [AI Agent Governance Report](<./Step-4-Standardize-AI-Usage/AI-Agent-Governance-Report.md>)
